<?php

namespace FM\Factory;

use Doctrine\ORM\EntityManager;
use FM\Traits\TQuery;

class Fm00004001TransferirTarefasFactory
{
    use TQuery;

    protected $connection;
    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getOperadorDestino($parametros, $listaLocais, $filtro)
    {
        $sql = "SELECT DISTINCT OPERADOR.CDOPERADOR, OPERADOR.NMOPERADOR, FCM_RELACHABOPER.NRHABILIDADE
                    FROM OPERADOR
                    JOIN FCM_FUNCIONARIOSHIERARQ
                    ON FCM_FUNCIONARIOSHIERARQ.CDOPERADOR = OPERADOR.CDOPERADOR
                    JOIN FCM_HIERARQUIAFUNC
                    ON FCM_HIERARQUIAFUNC.NRHIERARQUIAFUNC = FCM_FUNCIONARIOSHIERARQ.NRHIERARQUIAFUNC
                    JOIN FCM_RELACHABOPER
                    ON FCM_RELACHABOPER.CDOPERADOR = OPERADOR.CDOPERADOR
                    WHERE FCM_HIERARQUIAFUNC.NRLOCALCLIENTE IN (SELECT NRLOCALCLIENTE
                                            FROM FCM_LOCALCLI
                                            START WITH NRLOCALCLIENTE IN ($listaLocais)
                                            CONNECT BY PRIOR NRLOCALCLIENTEPAI = NRLOCALCLIENTE) 
                    AND FCM_RELACHABOPER.NRHABILIDADE = :NRHABILIDADE
                    $filtro
                    ORDER BY OPERADOR.NMOPERADOR";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql, $parametros);
    }

    public function transferirTarefa($parametros)
    {
        $sql = "UPDATE FCM_CHECKLISTAGEND
                    SET CDOPERADOR = :CDOPERADOR,
                        DTULTATU = SYSDATE,
                        CDOPERULTATU = :CDOPERULTATU,
                        NRORGULTATU = :NRORGULTATU,
                        DTHORAAGEND = :DTHORAAGEND,
                        DTHRFINALAGEND = :DTHRFINALAGEND
               WHERE NRCHECKLISTAGEND =  :NRCHECKLISTAGEND";

        $this->connection->executeStatement($sql, $parametros);
    }

    public function getTarefasPorOperador($operador)
    {
        $sql = "SELECT FCM_CHECKLISTAGEND.NRCHECKLISTAGEND, FCM_CHECKLISTAGEND.NRLOCALCLIENTE, FCM_CHECKLISTAGEND.NRCHECKLIST, FCM_CHECKLISTAGEND.NRFUNCIONARIO, FCM_CHECKLISTAGEND.IDSITUACAOAGEND, 
                        TO_CHAR(FCM_CHECKLISTAGEND.DTHORAAGEND,'DD/MM/YYYY HH24:MI') AS DTHORAAGEND, FCM_CHECKLISTAGEND.IDATIVO, 
                       FCM_CHECKLISTAGEND.NMCHECKLISTAGEND, TO_CHAR(FCM_CHECKLISTAGEND.DTHRFINALAGEND, 'DD/MM/YYYY HH24:MI') AS DTHRFINALAGEND, 
                       FCM_CHECKLISTAGEND.CDOPERADOR, FCM_RELACHABOPER.NRHABILIDADE, FCM_CHECKLISTAGEND.NRPRIORIDADETAREFA, FCM_PRIORIDADETAREFA.IDPRIORIDADE
                FROM FCM_CHECKLISTAGEND
                JOIN FCM_RELACHABOPER
                    ON FCM_RELACHABOPER.CDOPERADOR = FCM_CHECKLISTAGEND.CDOPERADOR
                LEFT JOIN FCM_PRIORIDADETAREFA
                    ON FCM_CHECKLISTAGEND.NRPRIORIDADETAREFA = FCM_PRIORIDADETAREFA.NRPRIORIDADETAREFA
                WHERE FCM_CHECKLISTAGEND.IDATIVO = 'S'
                AND FCM_CHECKLISTAGEND.CDOPERADOR =  $operador
                AND FCM_CHECKLISTAGEND.IDSITUACAOAGEND NOT IN ('4', '3')";

        return $this->connection->executeQuery($sql)->fetchAllAssociative();
    }
}
