/* eslint-disable */
import { Utilities } from '@/util/Utilities';
import {
    Button, DialogService, Form, Modal, ModalService, Select, Tabs, TextInput,
} from '@zeedhi/common';
import { Http, IEventParam, Metadata } from '@zeedhi/core';
import { IterableComponentRender, TekGrid } from '@zeedhi/teknisa-components-common';
import ColorPicker from '@/components/colorPicker/ZdColorPicker';
import { TekIterableComponentRender } from '@zeedhi/teknisa-components-vuetify';

export class Fm00003002ItensController {
    public modalItens!: Modal;

    public modalTarefasChecklist!: Modal;

    public codGridEditavel: String = '';
 
    public tituloModal: String = 'Adicionar Itens';

    public ultAtividadeSelecionada: String = '';

    public visibilidade() {
        const arrayTabs = Metadata.getInstance<Tabs>('tabs-checklist');
        const botao = Metadata.getInstance<Button>('botao-acionar-modal-itens');

        if (arrayTabs.tabs[arrayTabs.activeTab].name === 'tab-itens') {
            botao.isVisible = true;
        } else {
            botao.isVisible = false;
        }
    }

    public async abrirModalItens({ component }: any) {
        this.modalItens = await ModalService.createFromJsonPost('', { jsonPath: '/fm_00003_000_checklist/modal/fm_00003_002_salvar_itens' });
        await this.modalItens.show();
        const inputName = Metadata.getInstance<TextInput>('nomeTarefa');

        if (component.label === 'Alterar Cor') {
            inputName.isVisible = false;
            inputName.clearValidations(); 
            this.tituloModal = 'Alterar Cor';
            Metadata.getInstance<TextInput>('nratividade').value = component.name.split('_')[1];
        } else {
            inputName.isVisible = true;
            inputName.addValidation('required', {});
            this.tituloModal = 'Adicionar Itens'; 
        }
    }

    public fecharModalItens() {
        this.modalItens.hide();
        this.modalItens?.destroy();
    }

    public dialogInativarItem({ event, component }: any) {
        this.ultAtividadeSelecionada = component.name.split('_')[1];
        Utilities.showConfirmDeleteMessage(event, 'Fm00003002ItensController.inativarItem', 'Inativar Registro', 'Deseja realmente inativar o registro selecionado?');
    }

    public inativarItem() {
        Http.post('/inativarItem', {
            NRATIVIDADE: this.ultAtividadeSelecionada,
        }).then((response: any) => {
            if (response.data !== 'erro') {
                const cards = Metadata.getInstance<TekIterableComponentRender>('card-iterable-itens');
                DialogService.hide();
                Utilities.showSuccessMessage();
                cards.datasource.get();
            } else {
                Utilities.showErrorMessage('Não foi possível inativar o item selecionado pois ele está sendo utilizado.');
            }
        });
    }

    public async abrirModalTarefasChecklist() {
        this.modalTarefasChecklist = await ModalService.createFromJsonPost('', { jsonPath: '/fm_00003_000_checklist/modal/fm_00003_002_salvar_tarefas_checklist' });
        await this.modalTarefasChecklist.show();
    }

    public fecharModalTarefasChecklist() {
        this.modalTarefasChecklist.hide();
        this.modalTarefasChecklist?.destroy();
    }
    
    public salvarItens() {
        const form = Metadata.getInstance<Form>('form-itens');
        const cards = Metadata.getInstance<IterableComponentRender>('card-iterable-itens');

        if (form.validate()) {
            Utilities.save('/salvarItemChecklist', {
                NRATIVIDADE: form.value.nratividade,
                NMATIVIDADE: form.value.nomeTarefa,
                DSCORIDATIVIDADE: Metadata.getInstance<ColorPicker>('COLORPICKER').value,
            }).then(() => {
                Utilities.showSuccessMessage();
                cards.datasource.get();
                this.fecharModalItens();
            });
        } else {
            Utilities.alertMessage('Preencha todos os campos obrigatórios (*)!', 'error');
        }
    }

    public adicionarNovaLinha({ component }: IEventParam<TekGrid>) {
        const newId = 0;
        component.addNewRow({ NRITEMCHECKLIST: newId }, 'start');
        setTimeout(() => {
            const nameInput = Metadata.getInstance<TextInput>(`NRTAREFA_editable_${newId}`);
            nameInput.setFocus();
        }, 100);
    } 

    public changeCriterios({ component }: any) {
       const selectCriterio = Metadata.getInstance<Select>(`NRCRITERIOTAREFA_editable_${component.name.split('_')[2]}`);
       
       if (component.value) {
           selectCriterio.disabled = false;
           selectCriterio.datasource.setFilter({
               NRTAREFA: component.value, 
           });
       } else {
           selectCriterio.disabled = true;
       } 
    }

    public salvarTarefaChecklist({ component, event }: any) {
        event.preventDefault();
        const parametros = {
            NRATIVIDADE: component.name.split('_')[1],
            ROW: component.getEditedRows(),
        }

        if (Utilities.validateGrid(component)) {
            Utilities.save('/salvarTarefaChecklist', parametros).then(() => {
                component.datasource.get();
                component.cancelEditedRows();
            });
        }
    }

    public dialogInativarTarefasChecklist({ event, component }: any) {
        Utilities.showConfirmDeleteMessage(event, 'Fm00003002ItensController.inativarTarefasChecklist', 'Inativar Registros', 'Deseja realmente inativar todos os registros selecionados?');
        this.codGridEditavel = component.name.split('_')[1];
    }

    public inativarTarefasChecklist() {
        const grid = Metadata.getInstance<TekGrid>(`tek-grid-itens-com-atividades-criterios_${this.codGridEditavel}`);
        Utilities.deleteInfoGrid('/inativarTarefasChecklist', { component: grid }).then((response: any) => {
            grid.datasource.get();
            DialogService.hide();
            if (response.data === 'erro') {
                Utilities.showDialog('Atenção!', 'warning', 'Alguns registros não puderam ser inativados pois estão sendo utilizados!');
            }
        });
    }

    public setFilterGridTarefasChecklist({ component }: any) {
        component.datasource.setFilter({
            NRATIVIDADE: component.name.split('_')[1],
        });
    }
    
}
