import { Utilities } from '@/util/Utilities';
import {
    CheckboxMultiple, DateRange, Form, LoadingService, Modal, ModalService, Row, Select, SelectMultiple, TextInput, Time, Date as Data,
} from '@zeedhi/common';
import {
    Http, IDictionary, IEventParam, MemoryDatasource, Metadata,
} from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class Fm00004000TarefasMassaController {
    private modalPreencherInformacoes!: Modal;

    private cadastroTarefaMassa!: Modal;

    private modalConflito!: Modal;

    public visibilidadeGridItens: boolean = false;

    public visibilidadeForm: boolean = true;

    public parametrizacao = '';

    public disabledPreencher: boolean = true;

    public disabledPeriodo: boolean = false;

    public onMountedTipoInsercao({ component }: IEventParam<Select>) {
        component.datasource.data = [];
        (component.datasource as MemoryDatasource).allData = [];

        const valores = [
            {
                name: 'Considerar todos os dias',
                value: 1,
            },
            {
                name: 'Considerar dias úteis (Criar tarefa no próximo dia útil)',
                value: 2,
            },
            {
                name: 'Considerar dias úteis (Não criar tarefa)',
                value: 3,
            },
        ];

        setTimeout(() => {
            if (this.parametrizacao === 'N') {
                const codARemover = 2;
                const index = valores.findIndex((item: any) => item.value === codARemover);

                if (index !== -1) {
                    valores.splice(index, 1);
                }
            } else {
                valores.splice(1, 0, {
                    name: 'Considerar dias úteis (Criar tarefa no próximo dia útil)',
                    value: 2,
                });
            }

            component.datasource.updateData(valores);
        }, 500);
    }

    public changeRecorrencia({ component }: IEventParam<Select>) {
        const data = Metadata.getInstance<Data>('select-data');
        const xDias = Metadata.getInstance<TextInput>('input-x-dias');
        const periodo = Metadata.getInstance<DateRange>('select-periodo');
        const dtFinal = Metadata.getInstance<Data>('select-data-limite');

        switch (component.value) {
            case 'SR':
                this.disabledPeriodo = false;
                data.removeValidation('required');
                data.disabled = true;
                data.value = null;
                periodo.addValidation('required', {});
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.removeValidation('required');
                dtFinal.disabled = true;
                break;
            case 'M':
                data.addValidation('required', {});
                this.disabledPeriodo = true;
                data.disabled = false;
                periodo.removeValidation('required');
                periodo.value = null;
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            case 'MP':
                periodo.addValidation('required', {});
                this.disabledPeriodo = false;
                data.disabled = true;
                data.removeValidation('required');
                data.value = null;
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            case 'Q':
                data.addValidation('required', {});
                this.disabledPeriodo = true;
                data.disabled = false;
                periodo.removeValidation('required');
                periodo.value = null;
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            case 'QP':
                periodo.addValidation('required', {});
                this.disabledPeriodo = false;
                data.disabled = true;
                data.removeValidation('required');
                data.value = null;
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            case 'S':
                data.addValidation('required', {});
                this.disabledPeriodo = true;
                data.disabled = false;
                periodo.removeValidation('required');
                periodo.value = null;
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            case 'SP':
                periodo.addValidation('required', {});
                this.disabledPeriodo = false;
                data.disabled = true;
                data.removeValidation('required');
                data.value = null;
                xDias.disabled = true;
                xDias.value = null;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            case 'P':
                data.addValidation('required', {});
                this.disabledPeriodo = true;
                data.disabled = false;
                periodo.removeValidation('required');
                periodo.value = null;
                xDias.disabled = false;
                dtFinal.value = null;
                dtFinal.disabled = false;
                dtFinal.addValidation('required', {});
                break;
            default:
                break;
        }
    }

    public preencherGrid() {
        const form = Metadata.getInstance<Form>('form-preencher-massa');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-dados-agendamento');
        const tipoMarcacao = Metadata.getInstance<Select>('selectOpcoesMarcacao').value;
        const hora = Metadata.getInstance<Time>('selectHoraInicio').value;
        const duracao = Metadata.getInstance<TextInput>('selectDuracao').value;
        const operador = Metadata.getInstance<Select>('select-operador').value;
        const encarregado = Metadata.getInstance<Select>('select-encarregado').value;

        if (Utilities.validateForm(form)) {
            grid.selectedRows.forEach((element: any) => {
                const newRow: any = {
                    ...element,
                    IDTIPOMARCACAOTAREFA: tipoMarcacao,
                    HORAINICIO: hora,
                    DURACAO: duracao,
                    OPERADOR: operador,
                    ENCARREGADO: encarregado,
                };
                grid.datasource.put(newRow);
            });
            grid.datasource.get();
            grid.selectedRows = [];
            this.fecharModal();
        }
    }

    public habilitarAcao({ component }: IEventParam<TekGrid>) {
        this.disabledPreencher = (component.selectedRows.length <= 0);
    }

    public async criarModal() {
        this.modalPreencherInformacoes = await ModalService.createFromJson('fm_00004_000_tarefas/modal/fm_00004_006_modal_preencher_massa', true);
        this.modalConflito = await ModalService.createFromJson('fm_00004_000_tarefas/modal/fm_00004_004_modal_conflito_datas', true);
    }

    public abrirModal() {
        this.modalPreencherInformacoes.show();
        this.validaParametrizacao();

        setTimeout(() => {
            Metadata.getInstance<Form>('form-preencher-massa').clearForm();
            //  trecho do modal de preenchimento em massa
            const hora = Metadata.getInstance<Time>('selectHoraInicio');
            const duracao = Metadata.getInstance<TextInput>('selectDuracao');
            const att = Metadata.getInstance<Row>('row-atencao');

            if (this.parametrizacao !== 'N') {
                hora.disabled = true;
                // hora.removeValidation('required');
                duracao.disabled = true;
                duracao.removeValidation('required');
                duracao.removeValidation('minLength');
                att.isVisible = true;
            } else {
                hora.disabled = false;
                hora.addValidation('required');
                duracao.disabled = false;
                duracao.addValidation('required');
                att.isVisible = false;
            }

            Metadata.getInstance<Select>('select-operador').datasource.setFilter({
                NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').value,
            });

            Metadata.getInstance<Select>('select-encarregado').datasource.setFilter({
                NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').value,
            });
        }, 500);
    }

    public modConflito: boolean = false;

    public abrirModalConflito(parametros: any) {
        this.modalConflito.show();
        this.modConflito = true;
        setTimeout(() => {
           this.preencherGridConflitos(parametros);
        }, 500);
    }

    public destruirModal() {
        this.modalPreencherInformacoes?.destroy();
        this.modalConflito?.destroy();
    }

    public fecharModal() {
        this.modalPreencherInformacoes.hide();
    }

    public fecharModalConflito() {
        this.modalConflito.hide();
    }

    public habilitaOpcaoDias: boolean = true;

    public async exibirModalCadastroMassa({ event }: any) {
        event.preventDefault();
        this.cadastroTarefaMassa = await ModalService.createFromJsonPost('', { jsonPath: 'fm_00004_000_tarefas/modal/fm_00004_005_modal_cadastro_tarefas_massa' });
        this.validaParametrizacao();
        this.habilitaOpcaoDias = (this.parametrizacao === 'N');
        this.cadastroTarefaMassa.show();
        this.modConflito = false;
    }

    public async fecharModalTarefasMassa() {
        this.cadastroTarefaMassa.hide();
        this.cadastroTarefaMassa?.destroy();
    }

    public clickButtonToExpand({ component }: any) {
        const form = Metadata.getInstance<Form>(`formTarefas_${component.name}`);
        form.isVisible = !form.isVisible;
        component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
    }

    // INTEGRAÇÃO COM SM
    public changeContratos({ component }: any) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-dados-agendamento');
        if (grid.editing) {
            Metadata.getInstance<Select>(component.name).datasource.setFilter({
                NRESTRUTURAM: grid.datasource.currentRow.NRESTRUTURAM,
            });
            grid.columns[1].setLookupDataFilter({ NRESTRUTURAM: grid.datasource.currentRow.NRESTRUTURAM });
        }
    }

    public focusOperadores({ component }: any) {
        const grid = (this.modConflito) ? Metadata.getInstance<TekGrid>('tek-grid-conflito-datas') : Metadata.getInstance<TekGrid>('tek-grid-dados-agendamento');
        if (grid.editing) {
            component.datasource.setFilter({
                NRLOCALCLIENTE: Metadata.getInstance<Select>('NRLOCALCLIENTE').value,
                NRTAREFACHK: Metadata.getInstance<SelectMultiple>('NRTAREFACHK').value,
            });
        }
    }

    public validaVistoriaGrid({ component }: any) {
        // const vistoria = Metadata.getInstance<Select>('selectCriarVistoria');
        const observacao = Metadata.getInstance<Select>('selectObservacoesObrigatorias');
        const grid = Metadata.getInstance<TekGrid>('tek-grid-dados-agendamento');

        if (component.value === 1) {
            observacao!.datasource!.data!.push({
                value: '3',
                text: 'Somente na vistoria',
            });
            observacao!.datasource!.data!.push({
                value: '4',
                text: 'Na tarefa e na vistoria',
            });
            grid.columns[6].editable = true;
            // component.disabled = false;
            // component.addValidation('required');
        } else {
            grid.columns[6].editable = false;
            // component.value = null;
            // observacao.datasource?.get();
            // component.disabled = true;
            // component.removeValidation('required');
        }
    }

    public changeTipoDeLocal({ component }: IEventParam<Select>) {
        const tipoLocal = Metadata.getInstance<SelectMultiple>('NRTIPOLOCALCLI');
        const local = Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE');
        const checklist = Metadata.getInstance<Select>('NRCHECKLIST');

        if (component.value) {
            tipoLocal.disabled = false;
            tipoLocal.datasource.setFilter({
                CDCLIENTE: component.value,
            });
        } else {
            tipoLocal.disabled = true;
            tipoLocal.value = null;
            local.value = null;
            local.disabled = true;
            checklist.value = null;
        }
    }

    public changeLocal({ component }: IEventParam<SelectMultiple>) {
        const local = Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE');
        const checklist = Metadata.getInstance<Select>('NRCHECKLIST');

        if (component.value) {
            local.disabled = false;
            checklist.disabled = false;

            local.datasource.setFilter({
                NRTIPOLOCALCLI: component.value,
                UNICA: 'N',
                CDCLIENTE: Metadata.getInstance<Select>('CDCLIENTE').value,
            });

            checklist.datasource.setFilter({
                NRTIPOLOCALCLI: component.value,
                UNICA: 'N',
            });
        } else {
            local.value = null;
            local.disabled = true;
            checklist.value = null;
            checklist.disabled = true;
        }
    }

    public changeItensChecklist({ component }: IEventParam<Select>) {
        const itenschecklist = Metadata.getInstance<SelectMultiple>('NRATIVIDADECHK');
        if (component.value) {
            itenschecklist.disabled = false;
            itenschecklist.datasource.setFilter({
                NRCHECKLIST: component.value,
            });
        } else {
            itenschecklist.value = null;
            itenschecklist.disabled = true;
        }
    }

    public changeEscopo({ component }: IEventParam<SelectMultiple>) {
        const escopo = Metadata.getInstance<Select>('NRESCOPOSTAREFA');
        if (component.value) {
            escopo.disabled = false;
        } else {
            escopo.value = null;
            escopo.disabled = true;
        }
    }

    public changeTarefa({ component }: IEventParam<SelectMultiple>) {
        const tarefa = Metadata.getInstance<SelectMultiple>('NRTAREFACHK');
        const itenschecklist = Metadata.getInstance<Select>('NRATIVIDADECHK');

        if (component.value) {
            tarefa.disabled = false;
            tarefa.datasource.setFilter({
                NRATIVIDADECHK: itenschecklist.value,
            });
        } else {
            tarefa.value = null;
            tarefa.disabled = true;
        }
    }

    public setCriterios({ component }: IEventParam<SelectMultiple>) {
        const itenschecklist = Metadata.getInstance<Select>('NRATIVIDADECHK');
        const checklist = Metadata.getInstance<Select>('NRCHECKLIST');
        const checkbox = Metadata.getInstance<CheckboxMultiple>('NRCRITERIOTAREFACHK');
        const prioridade = Metadata.getInstance<Select>('select-prioridade');

        if (component.value) {
            checkbox.datasource?.setFilter({
                NRTAREFACHK: component.value,
                NRATIVIDADECHK: itenschecklist.value,
                NRCHECKLIST: checklist.value,
            });
            checkbox.datasource?.get();
            checkbox.isVisible = true;

            // trecho de código adicionado para validação de prioridade
            const arrayPrioritario: any = component.selectValue.find((array: any) => array.IDPRIORIDADE === 1);
            if (arrayPrioritario) {
                prioridade.disabled = true;
                prioridade.value = arrayPrioritario.NRPRIORIDADETAREFA;
            } else {
                prioridade.disabled = false;
                prioridade.value = null;
            }
        } else {
            component.value = null;
            checkbox.isVisible = false;
        }
    }

    public executorHora() {
        const dados: any = [];
        const grid = Metadata.getInstance<TekGrid>('tek-grid-dados-agendamento');

        grid.datasource.data.forEach((element: any) => {
            dados.push({
                HORAINICIO: element.HORAINICIO,
                DURACAO: element.DURACAO,
                FUNCIONARIO: element.OPERADOR,
                ENCARREGADO: element.ENCARREGADO,
                NRLOCALCLIENTE: element.NRLOCALCLIENTE,
                NRSEQCONTRATO: element.NRSEQCONTRATO,
                IDTIPOMARCACAOTAREFA: element.IDTIPOMARCACAOTAREFA,
                NRTIPOLOCALCLI: element.NRTIPOLOCALCLI,
                IGNORARTAREFA: 'N',
            });
        });
        return dados;
    }

    public inserirTarefa() {
        const formTarefas = Metadata.getInstance<Form>('formCadastroTarefas');
        const formCriterios = Metadata.getInstance<Form>('formTarefas_dropBoxCriterioAvaliacao');
        const formAgendamento = Metadata.getInstance<Form>('formTarefas_dropBoxDadosAgendamento');
        const checkBoxMultiple = Metadata.getInstance<CheckboxMultiple>('NRCRITERIOTAREFACHK');
        const diaSemana = Metadata.getInstance<SelectMultiple>('selectDiaSemana').value;
        const dataRange = Metadata.getInstance<DateRange>('select-periodo').value;
        const data = Metadata.getInstance<DateRange>('select-data').value;

        if (Utilities.validateForm(formTarefas) && Utilities.validateForm(formCriterios) && Utilities.validateForm(formAgendamento)) {
            const parametros = {
                NOMETAREFA: Metadata.getInstance<TextInput>('nomeTarefa').value,
                CDCLIENTE: Metadata.getInstance<Select>('CDCLIENTE').value,
                NRTIPOLOCALCLI: Metadata.getInstance<SelectMultiple>('NRTIPOLOCALCLI').value,
                NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').value,
                NRCHECKLIST: Metadata.getInstance<Select>('NRCHECKLIST').value,
                NRATIVIDADECHK: Metadata.getInstance<SelectMultiple>('NRATIVIDADECHK').value,
                NRESCOPOSTAREFA: Metadata.getInstance<SelectMultiple>('NRESCOPOSTAREFA').value,
                NRTAREFACHK: Metadata.getInstance<SelectMultiple>('NRTAREFACHK').value,
                NRCRITERIOTAREFACHK: checkBoxMultiple.datasource?.data.filter((box: any) => checkBoxMultiple.value.indexOf(box.NRCRITERIOTAREFACHK) >= 0),
                DATERANGE: (dataRange.length === 0) ? [data, data] : dataRange,
                DIASEMANA: diaSemana,
                VISTORIA: Metadata.getInstance<Select>('selectCriarVistoria').value,
                OBSERVACOES: Metadata.getInstance<Select>('selectObservacoesObrigatorias').value,
                EXECUTOR: this.executorHora(),
                RECORRENCIA: Metadata.getInstance<Select>('select-recorrencia').value,
                QTDDIAS: Metadata.getInstance<TextInput>('input-x-dias').value,
                DTTERMINO: Metadata.getInstance<Data>('select-data-limite').value,
                NRPRIORIDADETAREFA: Metadata.getInstance<Select>('select-prioridade').value,
            };
            this.salvarTarefa(parametros, this.executorHora(), false);
        }
    }

    public salvarTarefa(parametros: any, executor: any, conflito: boolean) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-tarefas');

        LoadingService.show();
        Http.post('/insertTarefasRecorrentes', {
            NOMETAREFA: parametros.NOMETAREFA,
            CDCLIENTE: parametros.CDCLIENTE,
            NRTIPOLOCALCLI: parametros.NRTIPOLOCALCLI,
            NRLOCALCLIENTE: parametros.NRLOCALCLIENTE,
            NRCHECKLIST: parametros.NRCHECKLIST,
            NRATIVIDADECHK: parametros.NRATIVIDADECHK,
            NRESCOPOSTAREFA: parametros.NRESCOPOSTAREFA,
            NRTAREFACHK: parametros.NRTAREFACHK,
            NRCRITERIOTAREFACHK: parametros.NRCRITERIOTAREFACHK,
            DATERANGE: parametros.DATERANGE,
            DIASEMANA: parametros.DIASEMANA,
            VISTORIA: parametros.VISTORIA,
            OBSERVACOES: parametros.OBSERVACOES,
            EXECUTOR: executor,
            RECORRENCIA: (conflito === true) ? 'SR' : parametros.RECORRENCIA,
            QTDDIAS: parametros.QTDDIAS,
            DTTERMINO: parametros.DTTERMINO,
            CONFLITO: conflito,
            PARAMETRIZACAO: this.parametrizacao,
            NRPRIORIDADETAREFA: parametros.NRPRIORIDADETAREFA,
        }).then((response: IDictionary) => {
            if (response.data !== 'OK') {
                this.abrirModalConflito(response.data);
                Utilities.alertMessage('Ainda há conflitos existentes. Resolva-os para prosseguir.', 'error');
            } else {
                Utilities.showSuccessMessage();
                this.fecharModalConflito();
                this.fecharModalTarefasMassa();
                grid.datasource.get();
            }
        }).catch((error: any) => {
            Utilities.showErrorMessage(error);
        }).finally(() => {
            LoadingService.hide();
        });
    }

    public dadosBanco: any = {};

    public preencherGridConflitos(parametros: any) {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-conflito-datas');
        grid.datasource.data = [];
        (grid.datasource as MemoryDatasource).allData = [];

        /* eslint-disable */
        let cont = 0;

        for (const key in parametros.DADOSCONFLITO) {
            const dados: any = {
                CHAVE: cont,
                NRLOCALCLIENTE: parametros.DADOSCONFLITO[key].NRLOCALCLIENTE,
                DATAINICIAL: parametros.DADOSCONFLITO[key].DATAINICIAL,
                DATAFINAL: parametros.DADOSCONFLITO[key].DATAFINAL,
                IDTIPOMARCACAOTAREFA: parametros.DADOSCONFLITO[key].IDTIPOMARCACAOTAREFA,
                HORAINICIO: parametros.DADOSCONFLITO[key].HORAINICIO,
                DURACAO: parametros.DADOSCONFLITO[key].DURACAO,
                OPERADOR: parametros.DADOSCONFLITO[key].FUNCIONARIO,
                ENCARREGADO: parametros.DADOSCONFLITO[key].ENCARREGADO,
                IGNORARTAREFA: 'N',
            };
            grid.datasource.post(dados);
            cont++;
        }

        grid.datasource.get();
        grid.columns[6].setLookupDataFilter({ NRLOCALCLIENTE: parametros.NRLOCALCLIENTE });
        grid.columns[7].setLookupDataFilter({ NRLOCALCLIENTE: parametros.NRLOCALCLIENTE });

        /* eslint-enable */
        this.dadosBanco = parametros;
    }

    public editedRows: any = '';

    public salvarConflitos() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-conflito-datas');
        const dados: any = [];

        if (this.editedRows.length !== 0) {
            grid.datasource.data.forEach((element: any) => {
                dados.push({
                    HORAINICIO: element.HORAINICIO,
                    DURACAO: element.DURACAO,
                    FUNCIONARIO: element.OPERADOR,
                    ENCARREGADO: element.ENCARREGADO,
                    NRLOCALCLIENTE: element.NRLOCALCLIENTE,
                    NRSEQCONTRATO: element.NRSEQCONTRATO,
                    IDTIPOMARCACAOTAREFA: element.IDTIPOMARCACAOTAREFA,
                    DATAINICIAL: element.DATAINICIAL.split(' ')[0],
                    DATAFINAL: element.DATAFINAL.split(' ')[0],
                    IGNORARTAREFA: element.IGNORARTAREFA,
                });
            });
            const parametros = {
                NOMETAREFA: this.dadosBanco.NOMETAREFA,
                CDCLIENTE: this.dadosBanco.CDCLIENTE,
                NRTIPOLOCALCLI: this.dadosBanco.NRTIPOLOCALCLI,
                NRLOCALCLIENTE: this.dadosBanco.NRLOCALCLIENTE,
                NRCHECKLIST: this.dadosBanco.NRCHECKLIST,
                NRATIVIDADECHK: this.dadosBanco.NRATIVIDADECHK,
                NRESCOPOSTAREFA: this.dadosBanco.NRESCOPOSTAREFA,
                NRTAREFACHK: this.dadosBanco.NRTAREFACHK,
                NRCRITERIOTAREFACHK: this.dadosBanco.NRCRITERIOTAREFACHK,
                DATERANGE: this.dadosBanco.DATERANGE,
                DIASEMANA: this.dadosBanco.DIASEMANA,
                VISTORIA: this.dadosBanco.VISTORIA,
                OBSERVACOES: this.dadosBanco.OBSERVACOES,
                QTDDIAS: this.dadosBanco.QTDDIAS,
                DTTERMINO: this.dadosBanco.DTTERMINO,
            };
            this.salvarTarefa(parametros, dados, true);
        } else {
            Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
        }
    }

    public validarGrid({ component }: IEventParam<TekGrid>) {
        if (component.isGridValid()) {
            Utilities.showSuccessMessage();
            this.editedRows = component.getEditedRows();
        } else {
            Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
        }
    }

    public validaParametrizacao() {
        Http.get('getParametroConflito').then((response) => {
            this.parametrizacao = (response.data.length !== 0) ? response.data[0].IDVALIDACRIATAREFA : null;
        });
    }

    public defineTarefa() {
        const grid = Metadata.getInstance<TekGrid>('tek-grid-dados-agendamento');
        grid.datasource.data = [];
        (grid.datasource as MemoryDatasource).allData = [];

        const locais = Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').selectValue;
        locais.forEach((element: any) => {
            const dados: any = {
                NMLOCALCLIENTE: element.NMLOCALCLIENTE,
                NRLOCALCLIENTE: element.NRLOCALCLIENTE,
                NRESTRUTURAM: element.NRESTRUTURAM,
                NRTIPOLOCALCLI: element.NRTIPOLOCALCLI,
            };
            grid.datasource.post(dados);
        });
        grid.datasource.get();
        grid.columns[5].setLookupDataFilter({ NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').value });
        grid.columns[6].setLookupDataFilter({ NRLOCALCLIENTE: Metadata.getInstance<SelectMultiple>('NRLOCALCLIENTE').value });
    }
}
